@@ -1,7 +1,7 @@
 """Utilities to help identify the current host and process."""
 
 
-def identify_host():
+def identify_host():  # pragma: no cover
     """Identify the host the current process is running on.
 
     This creates an entity identifier that identifies the host the
@@ -13,7 +13,7 @@ def identify_host():
     raise NotImplementedError  # TODO: Everything
 
 
-def identify_process():
+def identify_process():  # pragma: no cover
     """Identify the process.
 
     This creaets an entity identifier that identifies the process
